@@ -5,44 +5,33 @@
 
 /* Package information */
 #define PACKAGE           "task"
-#define VERSION           "2.5.1"
-#define PACKAGE_BUGREPORT "support@taskwarrior.org"
+#define VERSION           "2.5.3"
+#define PACKAGE_BUGREPORT "support@gothenburgbitfactory.org"
 #define PACKAGE_NAME      "task"
 #define PACKAGE_TARNAME   "task"
-#define PACKAGE_VERSION   "2.5.1"
-#define PACKAGE_STRING    "task 2.5.1"
+#define PACKAGE_VERSION   "2.5.3"
+#define PACKAGE_STRING    "task 2.5.3"
 
-#define CMAKE_BUILD_TYPE  ""
+#define CMAKE_BUILD_TYPE  "release"
 
 /* Installation details */
 #define TASK_RCDIR "/usr/local/share/doc/task/rc"
 
-/* Localization */
-#define PACKAGE_LANGUAGE 1
-#define LANGUAGE_ENG_USA 1
-#define LANGUAGE_ESP_ESP 2
-#define LANGUAGE_FRA_FRA 4
-#define LANGUAGE_DEU_DEU 3
-#define LANGUAGE_ITA_ITA 5
-#define LANGUAGE_POR_PRT 6
-#define LANGUAGE_EPO_RUS 7
-#define LANGUAGE_POL_POL 8
-#define LANGUAGE_JPN_JPN 9
-
 /* git information */
 #define HAVE_COMMIT
 
 /* cmake information */
 #define HAVE_CMAKE
-#define CMAKE_VERSION "3.4.3"
+#define CMAKE_VERSION "3.18.4"
 
 /* Compiling platform */
-/* #undef LINUX */
-#define DARWIN
+#define LINUX
+/* #undef DARWIN */
 /* #undef CYGWIN */
 /* #undef FREEBSD */
 /* #undef OPENBSD */
 /* #undef NETBSD */
+/* #undef DRAGONFLY */
 /* #undef HAIKU */
 /* #undef SOLARIS */
 /* #undef KFREEBSD */
@@ -59,10 +48,10 @@
 #define HAVE_TIMEGM
 
 /* Found st.st_birthtime struct member */
-#define HAVE_ST_BIRTHTIME
+/* #undef HAVE_ST_BIRTHTIME */
 
 /* Found get_current_dir_name */
-/* #undef HAVE_GET_CURRENT_DIR_NAME */
+#define HAVE_GET_CURRENT_DIR_NAME
 
 /* Found uuid_unparse_lower in the uuid library */
 #define HAVE_UUID_UNPARSE_LOWER
